@@ -2,6 +2,7 @@ from typing import Optional, Tuple
 import copy
 
 import numpy as np
+from pydantic import validator
 import scipy.sparse
 import scipy.sparse.linalg
 
@@ -47,6 +48,12 @@ class ESPSurfaceConstraintMatrix(base.Model):
     __imul__ = array_ops(np.ndarray.__imul__)
     __itruediv__ = array_ops(np.ndarray.__itruediv__)
 
+    @validator("matrix", pre=True)
+    def _validate_matrix(v):
+        if v is not None:
+            v = np.asarray(v)
+        return v
+
     @classmethod
     def with_n_dim(cls, n_dim: int):
         return cls(matrix=np.zeros((n_dim + 1, n_dim)))
@@ -162,8 +169,8 @@ class SparseGlobalConstraintMatrix(base.Model):
             mask=mask,
         )
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __post_init__(self, **kwargs):
+        super().__post_init__(**kwargs)
 
         self._n_atoms = len(self.constant_vector)
         if self.n_structure_array is None:
