@@ -81,6 +81,11 @@ class Job(base.Model):
                      "the number of CPUs.")
     )
 
+    @classmethod
+    def from_smiles(cls, smiles: str, order_by_map_number: bool = False, **kwargs):
+        mol = molecule.Molecule.from_smiles(smiles, order_by_map_number=order_by_map_number)
+        return cls(molecules=[mol], **kwargs)
+
     @property
     def charges(self):
         if self.stage_2_charges is None:
@@ -90,6 +95,10 @@ class Job(base.Model):
                 return self.stage_1_charges
         return self.stage_2_charges.charges
 
+    @property
+    def conformers(self):
+        return list(self.iter_conformers())
+
     @property
     def n_conformers(self):
         return sum(mol.n_conformers for mol in self.molecules)
@@ -98,6 +107,10 @@ class Job(base.Model):
     def n_orientations(self):
         return sum(mol.n_orientations for mol in self.molecules)
 
+    @property
+    def orientations(self):
+        return list(self.iter_orientations())
+
     def iter_conformers(self):
         for mol in self.molecules:
             yield from mol.conformers
