@@ -1,7 +1,8 @@
 
 import itertools
 import logging
-from typing import TYPE_CHECKING, Set, Tuple
+from typing import TYPE_CHECKING, Set, Tuple, Optional, List
+import warnings
 
 from typing_extensions import Literal
 import numpy as np
@@ -27,6 +28,7 @@ BONDTYPES = {
 
 logger = logging.getLogger(__name__)
 
+OPT_FF_NAMES = Literal["uff", "mmff94"]
 OFF_SMILES_ATTRIBUTE = "canonical_isomeric_explicit_hydrogen_mapped_smiles"
 
 
@@ -133,7 +135,7 @@ def assign_bond_order_and_charges_from_electrons(rdmol):
         # any residual unpaired electrons are turned into negative charge
         n_unpaired = n_unpaired_e(atom)[0]
         if n_unpaired > 0:
-            atom.SetFormalCharge(-n)
+            atom.SetFormalCharge(-n_unpaired)
             atom.SetNumRadicalElectrons(0)
             rdmol.UpdatePropertyCache(strict=False)
     Chem.Kekulize(rdmol)
@@ -246,7 +248,9 @@ def add_conformer_from_coordinates(rdmol: "rdkit.Chem.Mol",
 def generate_conformers(rdmol: "rdkit.Chem.Mol",
                         n_conformers: int = 0,
                         rms_tolerance: float = 1.5,
-                        random_seed=-1):
+                        random_seed=1,
+                        minimize: Optional[OPT_FF_NAMES] = None,
+                        ):
     """Generate conformers for an RDKit molecule.
 
     This does not clear existing conformers.
@@ -267,9 +271,12 @@ def generate_conformers(rdmol: "rdkit.Chem.Mol",
                                clearConfs=False,
                                randomSeed=random_seed,
                                ignoreSmoothingFailures=True)
+    if minimize:
+        minimize_conformer_geometries(rdmol, forcefield=minimize)
 
 
 def minimize_conformer_geometries(rdmol: "rdkit.Chem.Mol",
+                                  forcefield: OPT_FF_NAMES = "mmff94",
                                   minimize_max_iter: int = 2000):
     """Minimize conformer geometries of an RDKit molecule
 
@@ -278,10 +285,20 @@ def minimize_conformer_geometries(rdmol: "rdkit.Chem.Mol",
     minimize_max_iter: int (optional)
         Maximum number of iterations for minimization
     """
+    # TODO: make this more customizable
 
-    # TODO: is UFF good?
-    AllChem.UFFOptimizeMoleculeConfs(rdmol, numThreads=0,
-                                     maxIters=minimize_max_iter)
+    forcefield = forcefield.lower()
+    if forcefield == "uff":
+        AllChem.UFFOptimizeMoleculeConfs(rdmol, numThreads=0,
+                                         maxIters=minimize_max_iter)
+    elif forcefield == "mmff94":
+        AllChem.MMFFOptimizeMoleculeConfs(rdmol, numThreads=0,
+                                          maxIters=minimize_max_iter)
+    else:
+        raise ValueError(
+            f"Force field {forcefield} not supported. "
+            f"Please use one of {OPT_FF_NAMES}"
+        )
 
 
 def compute_mmff_charges(rdmol: "rdkit.Chem.Mol",
@@ -366,9 +383,14 @@ def select_elf_conformer_ids(rdmol: "rdkit.Chem.Mol",
     if n_conformers == 0:
         return
 
-    energies = compute_electrostatic_energy(rdmol, forcefield="MMFF94")
     all_conformer_ids = [c.GetId() for c in rdmol.GetConformers()]
 
+    try:
+        energies = compute_electrostatic_energy(rdmol, forcefield="MMFF94")
+    except ValueError as e:
+        warnings.warn(str(e))
+        return all_conformer_ids[:limit]
+
     sorting = np.argsort(energies)
     conversion = qcel.constants.conversion_factor(
         "(4 * pi * electric_constant) * kcal",
@@ -408,6 +430,7 @@ def generate_diverse_conformer_coordinates(molecule,
                                            energy_window: float = 30,
                                            n_max_conformers: int = 10,
                                            rms_tolerance: float = 0.05,
+                                           minimize: Optional[OPT_FF_NAMES] = None,
                                            ):
     if not isinstance(molecule, Chem.Mol):
         molecule = rdmol_from_qcelemental(molecule)
@@ -415,7 +438,9 @@ def generate_diverse_conformer_coordinates(molecule,
         molecule = Chem.RWMol(molecule)
 
     generate_conformers(molecule, n_conformers=n_conformer_pool,
-                        rms_tolerance=rms_tolerance)
+                        rms_tolerance=rms_tolerance,
+                        minimize=minimize,
+                        )
     return select_elf_conformer_coordinates(molecule,
                                             energy_window=energy_window,
                                             limit=n_max_conformers,
@@ -456,7 +481,7 @@ def molecule_to_rdkit(molecule):
     return Chem.Mol(rdmol)
 
 
-def molecule_from_rdkit(rdmol, molecule_cls, random_seed=-1, **kwargs):
+def molecule_from_rdkit(rdmol, molecule_cls, random_seed=1, **kwargs):
     rdmol = Chem.AddHs(rdmol)
     qcmol = rdmol_to_qcelemental(rdmol, random_seed=random_seed)
     kwargs = dict(**kwargs)
@@ -471,3 +496,36 @@ def molecule_from_rdkit(rdmol, molecule_cls, random_seed=-1, **kwargs):
 
 def get_connectivity(molecule):
     return get_rdkit_connectivity(molecule._rdmol)
+
+
+def GetSymmetricAtomIndices(
+    mol: Chem.Mol,
+    maxMatches: int = 10000,
+) -> List[Tuple[int, ...]]:
+    """Get atom indices of symmetric atoms
+
+    Returns
+    -------
+    symmetric_indices: List[Tuple[int, ...]]
+        In this list, one item is a sorted tuple of indices,
+        where each index indicates an atom that is symmetric
+        to all the other indices in the tuple.
+    """
+    # take care of resonance
+    matches = [
+        match
+        for resMol in Chem.ResonanceMolSupplier(mol)
+        for match in resMol.GetSubstructMatches(mol, uniquify=False,
+                                                maxMatches=maxMatches)
+    ]
+    atom_symmetries = set(tuple(sorted(set(x))) for x in zip(*matches))
+    return sorted([x for x in atom_symmetries if len(x) > 1])
+
+
+def get_symmetric_atom_indices(molecule):
+    # from psiresp.utils import require_package
+    # require_package("rdkit_utilities")
+
+    # from rdkit_utilities import GetSymmetricAtomIndices
+    rdmol = molecule.to_rdkit()
+    return GetSymmetricAtomIndices(rdmol)
