@@ -64,4 +64,9 @@ NME2ALA2_OPT_C1_ESP = datapath("esps/9ee96ceb2aec1b0d4b5c53ad3ae9e61d546f6717_es
 METHYLAMMONIUM_O1_GRID = datapath("esps/27c00e84078b824244612107da714196f49424cd_grid.dat")
 METHYLAMMONIUM_O1_ESP = datapath("esps/27c00e84078b824244612107da714196f49424cd_esp.dat")
 METHYLAMMONIUM_O2_GRID = datapath("esps/8776ca97115f78967cccc3dbc89c5530891000db_grid.dat")
-METHYLAMMONIUM_O2_ESP = datapath("esps/8776ca97115f78967cccc3dbc89c5530891000db_esp.dat")
\ No newline at end of file
+METHYLAMMONIUM_O2_ESP = datapath("esps/8776ca97115f78967cccc3dbc89c5530891000db_esp.dat")
+
+TRIFLUOROETHANOL_JOB = datapath("jobs/trifluoroethanol.json")
+
+FORMIC_ACID_JSON = datapath("molecules/formic_acid.json")
+FORMIC_ACID_WKDIR = datapath("manual_jobs/symmetry_dir/psiresp_working_directory")
