@@ -1,11 +1,12 @@
-import pytest
-from numpy.testing import assert_allclose, assert_equal
-
-from psiresp import psi4utils
 from psiresp.tests.datafiles import (DMSO, DMSO_ESP,
                                      DMSO_O1, DMSO_O1_ESP,
                                      DMSO_O2, DMSO_O2_ESP,
                                      )
+import pytest
+from numpy.testing import assert_allclose, assert_equal
+
+
+psi4utils = pytest.importorskip("psiresp.psi4utils")
 
 
 def test_psi4mol_from_qcmol(dmso_qcmol):
@@ -20,15 +21,15 @@ def test_get_connectivity(dmso_qcmol):
     assert connectivity.shape == (9, 3)
 
 
-def test_get_sp3_ch_indices(dmso_qcmol):
-    groups = psi4utils.get_sp3_ch_indices(dmso_qcmol)
-    reference = {
-        0: [1, 2, 3],
-        6: [7, 8, 9],
-    }
-    assert groups.keys() == reference.keys()
-    for k, v in groups.items():
-        assert_equal(v, reference[k])
+# def test_get_sp3_ch_indices(dmso_qcmol):
+#     groups = psi4utils.get_sp3_ch_indices(dmso_qcmol)
+#     reference = {
+#         0: [1, 2, 3],
+#         6: [7, 8, 9],
+#     }
+#     assert groups.keys() == reference.keys()
+#     for k, v in groups.items():
+#         assert_equal(v, reference[k])
 
 
 @pytest.mark.xfail(reason="fix qcrecord lookup and server")
